
# This file was generated by 'versioneer.py' (0.26) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-09-26T10:35:16+0300",
 "dirty": false,
 "error": null,
 "full-revisionid": "cb0c67a579b76bb0651c4fc54c18a0b7250a6515",
 "version": "3.21.0"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
