# Something is up with the pcluster constants
# from pcluster.constants import MAX_NUMBER_OF_QUEUES, MAX_NUMBER_OF_COMPUTE_RESOURCES_PER_CLUSTER
MAX_NUMBER_OF_QUEUES = 10
MAX_NUMBER_OF_COMPUTE_RESOURCES_PER_QUEUE = 5
MAX_NUMBER_OF_COMPUTE_RESOURCES = 50
MAX_NUMBER_OF_COMPUTE_RESOURCES_PER_CLUSTER = 50
